@@ -23,7 +23,7 @@ const notSettled = Symbol(`not-settled`);
  */
 
 /**
- * Run tasks with limited concurency.
+ * Run tasks with limited concurrency.
  * @template T
  * @param {number} limit - Limit of tasks that run at once.
  * @param {Task<T>[]} tasks - List of tasks to run.
@@ -703,37 +703,37 @@ async function esbuildMinify(input, sourceMap, minimizerOptions) {
     warnings:
       result.warnings.length > 0
         ? result.warnings.map((item) => {
-            return {
-              name: "Warning",
-              source: item.location && item.location.file,
-              line: item.location && item.location.line,
-              column: item.location && item.location.column,
-              plugin: item.pluginName,
-              message: `${item.text}${
-                item.detail ? `\nDetails:\n${item.detail}` : ""
-              }${
-                item.notes.length > 0
-                  ? `\n\nNotes:\n${item.notes
-                      .map(
-                        (note) =>
-                          `${
-                            note.location
-                              ? `[${note.location.file}:${note.location.line}:${note.location.column}] `
-                              : ""
-                          }${note.text}${
-                            note.location
-                              ? `\nSuggestion: ${note.location.suggestion}`
-                              : ""
-                          }${
-                            note.location
-                              ? `\nLine text:\n${note.location.lineText}\n`
-                              : ""
-                          }`
-                      )
-                      .join("\n")}`
-                  : ""
-              }`,
-            };
+            const plugin = item.pluginName
+              ? `\nPlugin Name: ${item.pluginName}`
+              : "";
+            const location = item.location
+              ? `\n\n${item.location.file}:${item.location.line}:${item.location.column}:\n  ${item.location.line} | ${item.location.lineText}\n\nSuggestion: ${item.location.suggestion}`
+              : "";
+            const notes =
+              item.notes.length > 0
+                ? `\n\nNotes:\n${item.notes
+                    .map(
+                      (note) =>
+                        `${
+                          note.location
+                            ? `[${note.location.file}:${note.location.line}:${note.location.column}] `
+                            : ""
+                        }${note.text}${
+                          note.location
+                            ? `\nSuggestion: ${note.location.suggestion}`
+                            : ""
+                        }${
+                          note.location
+                            ? `\nLine text:\n${note.location.lineText}\n`
+                            : ""
+                        }`
+                    )
+                    .join("\n")}`
+                : "";
+
+            return `${item.text} [${item.id}]${plugin}${location}${
+              item.detail ? `\nDetails:\n${item.detail}` : ""
+            }${notes}`;
           })
         : [],
   };
